﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;

namespace Exam_Khasanov_V16
{
    public partial class AddLaureateWindow : Window
    {
        private List<Laureate> laureates;  // Список лауреатов
        private Laureate selectedLaureate;  // Лауреат для редактирования

        // Конструктор для добавления нового лауреата
        public AddLaureateWindow(List<Laureate> laureates)
        {
            InitializeComponent();
            this.laureates = laureates;
            this.selectedLaureate = null;  // Здесь нет выбранного лауреата, так как мы добавляем нового

            // Инициализация данных (если нужно), например, очищаем текстовые поля
            NameTextBox.Text = "";
            YearTextBox.Text = "";
            CategoryTextBox.Text = "";
            CountryTextBox.Text = "";
            IsAliveCheckBox.IsChecked = false;
        }

        // Конструктор для редактирования существующего лауреата
        public AddLaureateWindow(List<Laureate> laureates, Laureate laureate)
        {
            InitializeComponent();
            this.laureates = laureates;
            this.selectedLaureate = laureate;

            // Заполнение полей окна данными выбранного лауреата
            NameTextBox.Text = laureate.Name;
            YearTextBox.Text = laureate.Year;
            CategoryTextBox.Text = laureate.Category;
            CountryTextBox.Text = laureate.Country;
            IsAliveCheckBox.IsChecked = laureate.IsAlive;
        }

        // Метод для удаления текста-плейсхолдера при фокусе на поле
        private void RemovePlaceholder(object sender, RoutedEventArgs e)
        {
            TextBox textBox = sender as TextBox;
            if (textBox != null && textBox.Foreground == System.Windows.Media.Brushes.Gray)
            {
                textBox.Foreground = System.Windows.Media.Brushes.Black;
                textBox.Text = "";
            }
        }

        // Метод для восстановления текста-плейсхолдера при потере фокуса
        private void AddPlaceholder(object sender, RoutedEventArgs e)
        {
            TextBox textBox = sender as TextBox;
            if (textBox != null && string.IsNullOrEmpty(textBox.Text))
            {
                textBox.Foreground = System.Windows.Media.Brushes.Gray;

                // Устанавливаем текст по умолчанию, если поле пустое
                if (textBox.Name == "NameTextBox")
                    textBox.Text = "Имя лауреата";
                else if (textBox.Name == "YearTextBox")
                    textBox.Text = "Год награждения";
                else if (textBox.Name == "CategoryTextBox")
                    textBox.Text = "Категория награды";
                else if (textBox.Name == "CountryTextBox")
                    textBox.Text = "Страна лауреата";
            }
        }

        // Обработчик кнопки "Сохранить"
        private void SaveButton_Click(object sender, RoutedEventArgs e)
        {
            string name = NameTextBox.Text;
            string year = YearTextBox.Text;
            string category = CategoryTextBox.Text;
            string country = CountryTextBox.Text;

            // Здесь можно добавить валидацию данных
            if (string.IsNullOrWhiteSpace(name) || name == "Имя лауреата")
            {
                MessageBox.Show("Пожалуйста, введите имя лауреата.", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            if (string.IsNullOrWhiteSpace(year) || year == "Год награждения")
            {
                MessageBox.Show("Пожалуйста, введите год награждения.", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            if (string.IsNullOrWhiteSpace(category) || category == "Категория награды")
            {
                MessageBox.Show("Пожалуйста, введите категорию награды.", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            if (string.IsNullOrWhiteSpace(country) || country == "Страна лауреата")
            {
                MessageBox.Show("Пожалуйста, введите страну лауреата.", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            // Здесь можно добавить сохранение данных в базу или другой источник

            // Если лауреат новый, добавляем его в список
            if (selectedLaureate == null)
            {
                laureates.Add(new Laureate
                {
                    Name = name,
                    Year = year,
                    Category = category,
                    Country = country,
                    IsAlive = IsAliveCheckBox.IsChecked ?? false
                });
            }
            else
            {
                // Если лауреат редактируется, обновляем его данные
                selectedLaureate.Name = name;
                selectedLaureate.Year = year;
                selectedLaureate.Category = category;
                selectedLaureate.Country = country;
                selectedLaureate.IsAlive = IsAliveCheckBox.IsChecked ?? false;
            }

            MessageBox.Show("Лауреат сохранен успешно!", "Успех", MessageBoxButton.OK, MessageBoxImage.Information);

            // Закрытие окна
            this.Close();
        }

        // Обработчик кнопки "Отмена"
        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }
        public string LaureateName { get; set; }
        public string LaureateYear { get; set; }
        public string LaureateCategory { get; set; }
        public string LaureateCountry { get; set; }
        public bool IsAlive { get; set; }

    }
}
